@@ -48,7 +48,7 @@ module Rspec
 
         # @deprecated Use `--webrat` instead.
         def webrat?
-          RSpec.deprecate("--webrat-matchers", "--webrat") if options[:webrat_matchers]
+          RSpec.deprecate("--webrat-matchers", :replacement => "--webrat") if options[:webrat_matchers]
           options[:webrat] || options[:webrat_matchers]
         end
 
