@@ -1,8 +1,8 @@
 require 'rspec/core'
 
 RSpec::configure do |c|
-  c.backtrace_clean_patterns << /vendor\//
-  c.backtrace_clean_patterns << /lib\/rspec\/rails/
+  c.backtrace_exclusion_patterns << /vendor\//
+  c.backtrace_exclusion_patterns << /lib\/rspec\/rails/
 end
 
 require 'rails/version'
