@@ -1,9 +1,9 @@
 require "spec_helper"
 
-describe RSpec::Rails::TestUnitAssertionAdapter do
-  include RSpec::Rails::TestUnitAssertionAdapter
+describe RSpec::Rails::MinitestAssertionAdapter do
+  include RSpec::Rails::MinitestAssertionAdapter
 
-  Test::Unit::Assertions.public_instance_methods.select{|m| m.to_s =~ /^(assert|flunk)/}.each do |m|
+  RSpec::Rails::Assertions.public_instance_methods.select{|m| m.to_s =~ /^(assert|flunk|refute)/}.each do |m|
     if m.to_s == "assert_equal"
       it "exposes #{m} to host examples" do
         assert_equal 3,3
@@ -18,11 +18,11 @@ describe RSpec::Rails::TestUnitAssertionAdapter do
     end
   end
 
-  it "does not expose internal methods of MiniTest" do
+  it "does not expose internal methods of Minitest" do
     methods.should_not include("_assertions")
   end
 
-  it "does not expose MiniTest's message method" do
+  it "does not expose Minitest's message method" do
     methods.should_not include("message")
   end
 end
